@@ -7,7 +7,7 @@ buildplace="${cowbuilderroot}/build"
 
 # all currently supported dists
 allnddists="nd+debian-buster nd+debian-bullseye nd+debian-bookworm nd+debian-trixie nd+debian-sid \
-            nd+ubuntu-bionic nd+ubuntu-focal nd+ubuntu-jammy"
+            nd+ubuntu-bionic nd+ubuntu-focal nd+ubuntu-jammy nd+ubuntu-noble"
 alldists="$allnddists debian-buster debian-bullseye debian-bookworm debian-trixie debian-sid"
 
 # default is debian
